pub enum CoverageTrustState {
Trusted,
Partial,
Untrusted,
}Expand description
Closed trust projection for one normalized coverage state.
Variants
Trusted
The selected producer reported complete coverage.
Partial
Some current facts are available while omissions remain explicit.
Untrusted
The selected facts are unavailable or not current enough to trust.