pub enum RelationDirection {
Outbound,
Inbound,
}Expand description
Direction of one detailed relation request from its selected anchor.
Variants
Outbound
Follow relations whose source is the active frontier.
Inbound
Follow relations whose retained target is the active frontier.