pub enum RelationNextCall {
Files {
folder: RepositoryNodePath,
},
Summary {
file: RepositoryFilePath,
},
SymbolSlice {
symbol: SymbolSelector,
},
}Expand description
Exact existing call that can consume one resolved local target directly.
Variants
Files
Continue folder navigation through the existing file route.
Fields

folder: RepositoryNodePathExact folder selector.
Summary
Inspect a file or package owner through the existing summary route.
Fields

file: RepositoryFilePathExact file selector.
SymbolSlice
Inspect one declaration through the existing exact slice route.
Fields

symbol: SymbolSelectorStable declaration selector.