pub fn file_summary_baseline_text(
report: &FileSummaryReport,
) -> ServiceResult<String>Expand description
Serialize the exact file summary payload for token telemetry.
Errors
Returns an error when the summary payload cannot be serialized.
pub fn file_summary_baseline_text(
report: &FileSummaryReport,
) -> ServiceResult<String>Serialize the exact file summary payload for token telemetry.
Returns an error when the summary payload cannot be serialized.