pub fn load_federated_relation_analysis(
stores: Vec<FederatedStore>,
query: &RelationAnalysisQuery,
control: Option<&IndexWorkControl>,
) -> ServiceResult<FederatedAnalysisDraft>Expand description
Load one federated closed analysis through already verified stores.
Errors
Returns an error before any response is produced when any participant, cursor, budget, query, cleanup, or post-read generation validation fails.