load_ranked_file_nodes

Function load_ranked_file_nodes 

pub fn load_ranked_file_nodes(
    store: &AtlasStore,
    query: &str,
    folder: Option<&str>,
    file_pattern: Option<&str>,
    limit: usize,
    include_content: bool,
) -> ServiceResult<Vec<IndexedNode>>
Load ranked file nodes and apply the shared repository-relative glob policy.

Errors

Returns an error when the file pattern is invalid or indexed nodes cannot be loaded.