pub fn parse_coverage_relation(value: &str) -> ServiceResult<GraphRelationKind>Expand description
Parse one public relation-family coverage filter.
Errors
Returns an error when the value is not a supported legacy or extended family.
pub fn parse_coverage_relation(value: &str) -> ServiceResult<GraphRelationKind>Parse one public relation-family coverage filter.
Returns an error when the value is not a supported legacy or extended family.