pub fn parse_coverage_state(value: &str) -> ServiceResult<CoverageState>Expand description
Parse one public coverage lifecycle filter.
Errors
Returns an error when the value is not one of the seven closed states.
pub fn parse_coverage_state(value: &str) -> ServiceResult<CoverageState>Parse one public coverage lifecycle filter.
Returns an error when the value is not one of the seven closed states.