pub fn parse_relation_direction(value: &str) -> ServiceResult<RelationDirection>Expand description
Parse one user-facing detailed-relation direction.
Errors
Returns an error for values other than outbound or inbound.
pub fn parse_relation_direction(value: &str) -> ServiceResult<RelationDirection>Parse one user-facing detailed-relation direction.
Returns an error for values other than outbound or inbound.