read_symbol_slice

Function read_symbol_slice 

pub fn read_symbol_slice(
    store: &AtlasStore,
    file: &Path,
    selector: &SymbolSliceSelector<'_>,
) -> ServiceResult<CodeSlice>
Read a symbol body by exact symbol name and optional disambiguators.

Errors

Returns an error when the symbol is absent, ambiguous, filtered out by the selector, or source cannot be read.