pub struct CodeSliceBudget { /* private fields */ }Expand description
Encoded-output ceiling shared by line and symbol slices.
Implementations
Sourceimpl CodeSliceBudget
impl CodeSliceBudget
Sourcepub const DEFAULT_OUTPUT_BYTES: u32
pub const DEFAULT_OUTPUT_BYTES: u32
Compatibility-preserving default for callers that omit a byte ceiling.
Sourcepub fn new(output_bytes: u32) -> ServiceResult<Self>
pub fn new(output_bytes: u32) -> ServiceResult<Self>
Validate one requested exact-output ceiling.
Errors
Returns an error when the limit is zero or above the shared product output ceiling.
Sourcepub const fn output_bytes(self) -> u32
pub const fn output_bytes(self) -> u32
Return the exact adapter-output ceiling.