CodeSliceDraft

Struct CodeSliceDraft 

pub struct CodeSliceDraft { /* private fields */ }
Unrendered exact slice with its selected adapter-output ceiling.

Implementations

Source

impl CodeSliceDraft

pub const fn slice(&self) -> &CodeSlice

Borrow the compatibility-preserving slice payload.

pub fn fit_output<F, E, O>(&self, encode: F) -> Result<O, E>
where F: FnOnce(&CodeSlice) -> Result<O, E>, E: From<ServiceError>, O: AsRef<[u8]>,

Encode this slice and enforce the selected adapter-output ceiling.

Errors

Returns an adapter error when encoding fails or the exact encoded output exceeds the selected byte ceiling.