DetailedRelationWork

Struct DetailedRelationWork 

pub struct DetailedRelationWork {
Show 13 fields pub returned_rows: u32, pub inspected_edges: u32, pub active_nodes: u32, pub visited_nodes: u32, pub retained_occurrences: u32, pub database_requested_rows: u32, pub database_returned_rows: u32, pub database_decoded_bytes: u64, pub hydrated_entities: u32, pub hydrated_purpose_paths: u32, pub retained_composition_bytes: u64, pub intermediate_bytes: u64, pub rendered_output_bytes: u64,
}
Exact aggregate work retained for one detailed relation page.

Fields

returned_rows: u32

Rows returned by this page.

inspected_edges: u32

Adjacency rows inspected by this page.

active_nodes: u32

Unique traversal nodes retained in the cursor state.

visited_nodes: u32

Unique visited nodes retained in the cursor state.

retained_occurrences: u32

Exact occurrences retained by this page.

database_requested_rows: u32

Compact keys supplied to bounded database batches.

database_returned_rows: u32

Fully reconstructed rows returned by bounded database batches.

database_decoded_bytes: u64

Exact raw SQLite payload bytes decoded by bounded database batches.

hydrated_entities: u32

Aggregate batch-local unique graph endpoints reconstructed by database reads.

hydrated_purpose_paths: u32

Aggregate batch-local unique purpose-owner paths hydrated by database reads.

retained_composition_bytes: u64

Exact serialized bytes retained by one composed anchor and row set.

intermediate_bytes: u64

Aggregate decoded database, encoded cursor, and peak composition bytes.

rendered_output_bytes: u64

Exact adapter bytes, filled by the selected output renderer.