pub struct FederatedDetailedRelationDraft { /* private fields */ }Expand description
Unrendered federated detailed response that fits the exact adapter envelope.
Implementations
Sourceimpl FederatedDetailedRelationDraft
impl FederatedDetailedRelationDraft
Sourcepub fn fit_output<F, E>(
self,
control: Option<&IndexWorkControl>,
encode: F,
) -> Result<(FederatedDetailedRelationReport, String), E>
pub fn fit_output<F, E>( self, control: Option<&IndexWorkControl>, encode: F, ) -> Result<(FederatedDetailedRelationReport, String), E>
Fit the largest primary-row prefix to the exact federated adapter envelope.
Errors
Returns an adapter error when rendering fails, cancellation fires, a cursor cannot be wrapped, or the empty federated envelope is oversized.