SymbolSliceSelector

Struct SymbolSliceSelector 

pub struct SymbolSliceSelector<'a> {
    pub name: &'a str,
    pub parent: Option<&'a str>,
    pub kind: Option<&'a str>,
    pub signature: Option<&'a str>,
    pub line: Option<usize>,
}
Optional selectors for disambiguating a symbol slice.

Fields

name: &'a str

Symbol name to locate.

parent: Option<&'a str>

Optional parent symbol, such as a class or struct name.

kind: Option<&'a str>

Optional symbol kind, such as function, method, or struct.

signature: Option<&'a str>

Optional exact normalized declaration signature.

line: Option<usize>

Optional line that must fall inside the selected symbol range.