pub fn build_next_report_with_selection(
store: &AtlasStore,
query: &str,
limit: Option<usize>,
content_selection: ContentSelection,
) -> ServiceResult<NextStepReport>Expand description
Build an indexed recommendation report with classified file selection.
Errors
Returns an error when indexed folder, file, or classification metadata cannot be loaded.