pub fn load_agent_efficiency_comparison(
store: &AtlasStore,
benchmark_results: Option<&Path>,
) -> ServiceResult<AgentEfficiencyComparison>Expand description
Load optional benchmark evidence for one exact selected project.
Errors
Returns an error when the selected project is unavailable or changes while the bounded artifact is loaded.