pub fn read_indexed_code_slice(
store: &AtlasStore,
file: &Path,
start_line: usize,
end_line: Option<usize>,
) -> ServiceResult<CodeSlice>Expand description
Read an exact line slice from an indexed project file.
Errors
Returns an error when the file is not an indexed project file, line numbers are invalid, or source cannot be read.