pub fn read_indexed_code_slice_with_selection(
store: &AtlasStore,
file: &Path,
start_line: usize,
end_line: Option<usize>,
content_selection: ContentSelection,
) -> ServiceResult<CodeSlice>Expand description
Read an exact indexed line slice after enforcing classified-content selection.
Errors
Returns an error when the file is outside the explicit selection, is not an indexed project file, has invalid line numbers, or source cannot be read.