pub fn read_symbol_slice_from_source_bounded_with_selection(
store: &AtlasStore,
file: &Path,
selector: &SymbolSliceSelector<'_>,
source: &str,
output_budget: CodeSliceBudget,
content_selection: ContentSelection,
) -> ServiceResult<CodeSliceDraft>Expand description
Read a bounded symbol body from verified source after classified selection.
Errors
Returns an error when the file is outside the explicit selection, the symbol cannot be selected exactly, or its body cannot fit the output budget.