pub fn validate_federated_root_count(count: usize) -> ServiceResult<()>Expand description
Validate the explicit root count before an adapter opens any database.
Errors
Returns an error unless the call supplies between two and eight roots.
pub fn validate_federated_root_count(count: usize) -> ServiceResult<()>Validate the explicit root count before an adapter opens any database.
Returns an error unless the call supplies between two and eight roots.