pub struct CodeSliceDraft { /* private fields */ }Expand description
Unrendered exact slice with its selected adapter-output ceiling.
Implementations
Sourceimpl CodeSliceDraft
impl CodeSliceDraft
Sourcepub fn fit_output<F, E, O>(&self, encode: F) -> Result<O, E>
pub fn fit_output<F, E, O>(&self, encode: F) -> Result<O, E>
Encode this slice and enforce the selected adapter-output ceiling.
Errors
Returns an adapter error when encoding fails or the exact encoded output exceeds the selected byte ceiling.